#!/usr/bin/env ruby
require("gsl")

v = Vector.alloc([17.2, 18.1, 16.5, 18.3, 12.6])
p Stats.mean(v)
p Stats.variance(v)
p Stats.sd(v)
p Stats.max(v)
p Stats.min(v)
